@@ -1,7 +1,7 @@
 import pymongo
 from financial_fundamentals.mongo_drivers import MongoIntervalseries,\
     MongoTimeseries
-from financial_fundamentals.time_series_cache import FinancialDataRangesCache,\
+from financial_fundamentals.time_series_cache import FinancialIntervalCache,\
     FinancialDataTimeSeriesCache
 from financial_fundamentals.prices import get_prices_from_yahoo
 
@@ -16,11 +16,11 @@ def mongo_fundamentals_cache(metric, mongo_host='localhost', mongo_port=27017,
                              filing_getter=HTMLEdgarDriver):
     mongo_client = pymongo.MongoClient(mongo_host, mongo_port)
     mongo_collection = mongo_client.fundamentals.fundamentals
-    db = MongoIntervalseries(collection=mongo_collection, 
+    db = MongoIntervalseries(mongo_collection=mongo_collection, 
                          metric=metric.name)
     metric_getter = AccountingMetricGetter(metric=metric,
                                            filing_getter=filing_getter)
-    cache = FinancialDataRangesCache(get_data=metric_getter.get_data, database=db)
+    cache = FinancialIntervalCache(get_data=metric_getter.get_data, database=db)
     return cache
 
 def mongo_price_cache(mongo_host='localhost', mongo_port=27017):
@@ -39,7 +39,7 @@ def sqlite_price_cache(db_file_path=DEFAULT_PRICE_PATH):
     return FinancialDataTimeSeriesCache.build_sqlite_price_cache(sqlite_file_path=db_file_path, 
                                                                  table='prices', 
                                                                  metric='Adj Close')
-    
+
 DEFAULT_FUNDAMENTALS_PATH = os.path.join(os.path.expanduser('~'), '.fundamentals.sqlite')
 def sqlite_fundamentals_cache(metric, 
                               db_file_path=DEFAULT_FUNDAMENTALS_PATH, 
@@ -51,6 +51,6 @@ def sqlite_fundamentals_cache(metric,
     metric_getter = AccountingMetricGetter(metric=metric, 
                                            filing_getter=filing_getter)
     
-    cache = FinancialDataRangesCache(get_data=metric_getter.get_data, 
+    cache = FinancialIntervalCache(get_data=metric_getter.get_data, 
                                      database=driver)
     return cache
\ No newline at end of file
