@@ -9,14 +9,16 @@ import unittest
 from datetime import date
 from tests.infrastructure import turn_on_request_caching, TEST_DOCS_DIR
 import os
-from financial_fundamentals.edgar import HTMLEdgarDriver, XBRLNotAvailable,\
-    Filing
+from financial_fundamentals.edgar import HTMLEdgarDriver, Filing, filing_sort_key_func,\
+    FilingNotAvailableForDate, NoFilingsNotAvailable
 import datetime
 import urlparse
+import blist
 
 class TestsEdgar(unittest.TestCase):
     def setUp(self):
         turn_on_request_caching()
+        HTMLEdgarDriver._ticker_filings = {}
 
     def test_get_filiing(self):
         filing = HTMLEdgarDriver.get_filing(ticker='aapl', 
@@ -56,7 +58,7 @@ class TestsEdgar(unittest.TestCase):
                                                                filing_type, 
                                                                date_after, 
                                                                )
-        self.assertRaises(XBRLNotAvailable, finds_no_filings)
+        self.assertRaises(NoFilingsNotAvailable, finds_no_filings)
 
     def test_sort_order(self):
         filing_dates = [datetime.date(2012, 12, 1),
@@ -95,8 +97,28 @@ class TestsEdgar(unittest.TestCase):
         filing = HTMLEdgarDriver._get_filing_from_document_page(document_page_url=document_page_that_failed)
         self.assertEqual(filing._document._xbrl_url.split('/')[-1], 'jcp-20130504.xml')
         
+    def test_xbrl_not_available_yet(self):
+        '''Verify behavior when looking for a document prior to company's first XBRL filing.
+        
+        '''
+        filing_date=date(2012, 11, 30)
+        sorted_filings = blist.sortedlist(key=filing_sort_key_func)
+        sorted_filings.add(Filing(filing_date=filing_date, document=None))
+        edgar_driver = HTMLEdgarDriver
+        get_sorted_filings_mock = mock.Mock()
+        get_sorted_filings_mock.return_value = sorted_filings
+        edgar_driver._get_sorted_filings = get_sorted_filings_mock
+        exception = None
+        try:
+            edgar_driver.get_filing(ticker=None, filing_type=None, 
+                                    date_after=filing_date - datetime.timedelta(days=1))
+        except FilingNotAvailableForDate as e:
+            exception = e
+        self.assertIsInstance(exception, FilingNotAvailableForDate)
+        self.assertEqual(exception.end, filing_date + datetime.timedelta(days=1))
+        
 if __name__ == '__main__':
     suite = unittest.TestSuite()
-    suite.addTest(TestsEdgar('test_JCP'))
+    suite.addTest(TestsEdgar('test_xbrl_not_available_yet'))
     unittest.TextTestRunner().run(suite)
     
\ No newline at end of file
